/*
* Copyright (C) 2005 Bourgeon Jrme, Macherel Bruno
*
* This file is part of Dolphin
*
* Dolphin : An open source J2EE Deployment Tool JSR-88 compliant
* Contact: ishmael-dev@objectweb.org
*
* Dolphin is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or any later version.
*
* Dolphin is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with Dolphin; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA
*/
package org.objectweb.dolphin.rcp;

import org.eclipse.jface.action.GroupMarker;
import org.eclipse.jface.action.IContributionItem;
import org.eclipse.jface.action.ICoolBarManager;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.jface.action.ToolBarContributionItem;
import org.eclipse.jface.action.ToolBarManager;
import org.eclipse.swt.SWT;
import org.eclipse.ui.IWorkbenchActionConstants;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.actions.ActionFactory;
import org.eclipse.ui.actions.ContributionItemFactory;
import org.eclipse.ui.actions.ActionFactory.IWorkbenchAction;
import org.eclipse.ui.application.ActionBarAdvisor;
import org.eclipse.ui.application.IActionBarConfigurer;
import org.objectweb.dolphin.actions.ChangeWorkspaceAction;


/**
 * This is the actionBarAdvisor for Dolphin
 * @author Bourgeon Jrme, Macherel Bruno
 *
 */
public class DolphinActionBarAdvisor extends ActionBarAdvisor {
	//File menu
	private IWorkbenchAction exitAction;
	//Edit menu
	private IWorkbenchAction undoAction;
	private IWorkbenchAction redoAction;
	private IWorkbenchAction cutAction;
	private IWorkbenchAction copyAction;
	private IWorkbenchAction pasteAction;
	private IWorkbenchAction deleteAction;
	private IWorkbenchAction selectAllAction;
	//Window menu
	private IContributionItem perspectiveList;
	private IContributionItem viewList;
	private IWorkbenchAction preferenceAction;
	private IWorkbenchAction openWindowAction;
	//Help menu
	private IWorkbenchAction helpAction;
	private IWorkbenchAction aboutAction;

	private ChangeWorkspaceAction changeWorkspace;

	/**
	 * @param configurer
	 */
	public DolphinActionBarAdvisor(IActionBarConfigurer configurer) {
		super(configurer);
	}

	//	 public void fillActionBars(IWorkbenchWindow window,
	//	            IActionBarConfigurer configurer, int flags) {
	//	        // super.fillActionBars(window, configurer, flags);
	//	        if ((flags & ActionBarAdvisor.FILL_MENU_BAR) != 0) {
	//	            fillMenuBar(window, configurer);
	//	        }
	//	    }

	/**
	 * @see org.eclipse.ui.application.ActionBarAdvisor#makeActions(org.eclipse.ui.IWorkbenchWindow)
	 */
	protected void makeActions(final IWorkbenchWindow window) {

		//File menu
		exitAction=ActionFactory.QUIT.create(window);
		register(exitAction);

		//Edit menu
		undoAction=ActionFactory.UNDO.create(window);
		register(undoAction);
		redoAction=ActionFactory.REDO.create(window);
		register(redoAction);
		copyAction=ActionFactory.COPY.create(window);
		register(copyAction);
		cutAction=ActionFactory.CUT.create(window);
		register(cutAction);
		pasteAction=ActionFactory.PASTE.create(window);
		register(pasteAction);
		deleteAction=ActionFactory.DELETE.create(window);
		register(deleteAction);
		selectAllAction=ActionFactory.SELECT_ALL.create(window);
		register(selectAllAction);

		//Window
		perspectiveList = ContributionItemFactory.PERSPECTIVES_SHORTLIST.create(window);
		viewList = ContributionItemFactory.VIEWS_SHORTLIST.create(window);
		preferenceAction=ActionFactory.PREFERENCES.create(window);
		register(preferenceAction);
		openWindowAction=ActionFactory.OPEN_NEW_WINDOW.create(window);
		register(openWindowAction);

		//Help
		helpAction=ActionFactory.HELP_CONTENTS.create(window);
		register(helpAction);
		aboutAction=ActionFactory.ABOUT.create(window);
		register(aboutAction);

		changeWorkspace = new ChangeWorkspaceAction(window);
		register(changeWorkspace);


	}

	/**
	 * @see org.eclipse.ui.application.ActionBarAdvisor#fillMenuBar(org.eclipse.jface.action.IMenuManager)
	 */
	protected void fillMenuBar(IMenuManager menubar) {
		createFileMenu(menubar);
		createEditMenu(menubar);
		createWindowMenu(menubar);
		createHelpMenu(menubar);
	}

	/**
	 * createFileMenu
	 * @param menubar
	 */
	private void createFileMenu(IMenuManager menubar) {
		MenuManager fileMenu = new MenuManager(Messages.getString("FileMenu"), IWorkbenchActionConstants.M_FILE);
		menubar.add(fileMenu);
		menubar.add(new GroupMarker(IWorkbenchActionConstants.FILE_START));
		menubar.add(new GroupMarker(IWorkbenchActionConstants.MB_ADDITIONS));
		fileMenu.add(changeWorkspace);
		fileMenu.add(exitAction);
		menubar.add(new GroupMarker(IWorkbenchActionConstants.FILE_END));
	}

	/**
	 * createEditMenu
	 * @param menubar
	 */
	private void createEditMenu(IMenuManager menubar) {
		MenuManager editmenu = new MenuManager(Messages.getString("EditMenu"),IWorkbenchActionConstants.M_EDIT); //$NON-NLS-1$
		menubar.add(editmenu);
		menubar.add(new GroupMarker(IWorkbenchActionConstants.EDIT_START));
		editmenu.add(undoAction);
		editmenu.add(redoAction);
		editmenu.add(new Separator());
		editmenu.add(copyAction);
		editmenu.add(cutAction);
		editmenu.add(pasteAction);
		editmenu.add(deleteAction);
		editmenu.add(new Separator());
		editmenu.add(selectAllAction);
		menubar.add(new GroupMarker(IWorkbenchActionConstants.EDIT_END));
		menubar.add(new Separator(IWorkbenchActionConstants.MB_ADDITIONS));
	}

	/**
	 * createWindowMenu
	 * @param menubar
	 */
	private void createWindowMenu(IMenuManager menubar) {
		MenuManager menuWindow = new MenuManager(Messages.getString("WindowMenu"), IWorkbenchActionConstants.M_WINDOW);//$NON-NLS-1$
		MenuManager perspectiveMenu = new MenuManager(Messages.getString("WindowMenu_OpenPerspective"), "openPerspective"); //$NON-NLS-1$ //$NON-NLS-2$
		perspectiveMenu.add(perspectiveList);
		menuWindow.add(perspectiveMenu);
		MenuManager viewMenu = new MenuManager(Messages.getString("WindowMenu_ShowView")); //$NON-NLS-1$
		viewMenu.add(viewList);
		menuWindow.add(viewMenu);
		menuWindow.add(new Separator(IWorkbenchActionConstants.MB_ADDITIONS));
		menuWindow.add(preferenceAction);
		menuWindow.add(openWindowAction);
		menubar.add(menuWindow);

	}

	/**
	 * createHelpMenu
	 * @param menubar
	 */
	private void createHelpMenu(IMenuManager menubar) {
		MenuManager menuHelp = new MenuManager(Messages.getString("HelpMenu"), IWorkbenchActionConstants.M_HELP); //$NON-NLS-1$
		// Welcome or intro page would go here
		menuHelp.add(helpAction);
		// Tips and tricks page would go here
		menuHelp.add(new GroupMarker(IWorkbenchActionConstants.HELP_START));
		menuHelp.add(new GroupMarker(IWorkbenchActionConstants.HELP_END));
		menuHelp.add(new GroupMarker(IWorkbenchActionConstants.MB_ADDITIONS));
		// About should always be at the bottom
		// To use the real RCP About dialog uncomment these lines
		menuHelp.add(new Separator());
		menuHelp.add(aboutAction);
		menubar.add(menuHelp);

	}

	/**
	 * @see org.eclipse.ui.application.ActionBarAdvisor#fillCoolBar(org.eclipse.jface.action.ICoolBarManager)
	 */
	protected void fillCoolBar(ICoolBarManager coolbar){
		IToolBarManager toolbar = new ToolBarManager(SWT.FLAT|SWT.RIGHT);
		coolbar.add(new ToolBarContributionItem(toolbar,"main"));
		toolbar.add(helpAction);
		toolbar.add(aboutAction);

	}

}
